@@ -1,9 +1,11 @@
-import click
+from metrics_layer.core.utils import lazy_import
+
+lazy_click = lazy_import("click")
 
 from .seeding import SeedMetricsLayer
 
 
-@click.group()
+@lazy_click.group()
 def cli_group():
     pass
 
@@ -15,10 +17,10 @@ def init(arg=None, opt={}):
 
 
 @cli_group.command()
-@click.option("--connection", default=None, help="The name of the connection to use for the database")
-@click.option("--database", help="The name of the database to use for seeding")
-@click.option("--schema", default=None, help="The name of the schema to use for seeding")
-@click.argument("profile")
+@lazy_click.option("--connection", default=None, help="The name of the connection to use for the database")
+@lazy_click.option("--database", help="The name of the database to use for seeding")
+@lazy_click.option("--schema", default=None, help="The name of the schema to use for seeding")
+@lazy_click.argument("profile")
 def seed(profile, connection, database, schema):
     """Seed a metrics layer project by referencing the existing database"""
     SeedMetricsLayer._init_directories()
@@ -27,7 +29,7 @@ def seed(profile, connection, database, schema):
 
 
 @cli_group.command()
-@click.argument("profile")
+@lazy_click.argument("profile")
 def validate(profile):
     """Validate a metrics layer project, internally, without hitting the database"""
     metrics_layer = SeedMetricsLayer._init_profile(profile)
@@ -35,11 +37,11 @@ def validate(profile):
 
     if len(errors) == 0:
         n_explores = len(metrics_layer.config.project.explores())
-        click.echo(f"Project passed (checked {n_explores} explore{'s' if n_explores > 1 else ''})!")
+        lazy_click.echo(f"Project passed (checked {n_explores} explore{'s' if n_explores > 1 else ''})!")
     else:
-        click.echo(f"Found {len(errors)} error{'s' if len(errors)> 1 else ''} in the project:\n")
+        lazy_click.echo(f"Found {len(errors)} error{'s' if len(errors)> 1 else ''} in the project:\n")
         for error in errors:
-            click.echo(f"\n{error}\n")
+            lazy_click.echo(f"\n{error}\n")
 
 
 if __name__ == "__main__":
