@@ -1,10 +1,11 @@
 import os
 from copy import deepcopy
 
-import lkml
-import yaml
+from metrics_layer.core.utils import lazy_import, merge_nested_dict
+
+lazy_lkml = lazy_import("lkml")
+lazy_yaml = lazy_import("yaml")
 
-from metrics_layer.core.utils import merge_nested_dict
 
 from .github_repo import BaseRepo
 
@@ -35,12 +36,12 @@ class ProjectReader:
         for model in self.models:
             file_name = model["name"] + "_model.yml"
             with open(os.path.join(path, file_name), "w") as f:
-                yaml.dump(model, f)
+                lazy_yaml.dump(model, f)
 
         for view in self.views:
             file_name = view["name"] + "_view.yml"
             with open(os.path.join(path, file_name), "w") as f:
-                yaml.dump(view, f)
+                lazy_yaml.dump(view, f)
 
     def load(self) -> None:
         base_models, base_views = self._load_repo(self.base_repo)
@@ -166,7 +167,7 @@ class ProjectReader:
     @staticmethod
     def read_lkml_file(path: str):
         with open(path, "r") as file:
-            lkml_dict = lkml.load(file)
+            lkml_dict = lazy_lkml.load(file)
         return lkml_dict
 
     @staticmethod
@@ -180,5 +181,5 @@ class ProjectReader:
     @staticmethod
     def read_yaml_file(path: str):
         with open(path, "r") as file:
-            yaml_dict = yaml.safe_load(file)
+            yaml_dict = lazy_yaml.safe_load(file)
         return yaml_dict
